// AUTO-GENERATED BY UpdateGenVersion.bat 5ee56140130f44e5aa4fe38a4f51e9fdd53542be
const char GenVersion_Version[] = "0.4.4-dev";
const char GenVersion_Commit[] = "5ee56140130f44e5aa4fe38a4f51e9fdd53542be";
